@@ -22,12 +22,12 @@ if str(ROOT / 'trackers' / 'strong_sort') not in sys.path:
 
 ROOT = Path(os.path.relpath(ROOT, Path.cwd()))  # relative
 
-from yolov5.models.common import DetectMultiBackend
+from .yolov5.models.common import DetectMultiBackend
 
-from yolov5.utils.general import non_max_suppression, scale_boxes
-from yolov5.utils.torch_utils import select_device
-from yolov5.utils.dataloaders import letterbox
-from yolov5.utils.general import check_img_size
+from .yolov5.utils.general import non_max_suppression, scale_boxes
+from .yolov5.utils.torch_utils import select_device
+from .yolov5.utils.dataloaders import letterbox
+from .yolov5.utils.general import check_img_size
 from trackers.multi_tracker_zoo import create_tracker
 import cv2
 
